@@ -104,7 +104,8 @@
 #'           main = "Main Title", type = "p", pch = 16,
 #'           scientific = FALSE, conversion.factor = 3.28)
 #'
-#' y <- data.frame(lapply(1:3, function(i) sample(n, replace = TRUE)))
+#' y <- data.frame(lapply(1:3, function(i) sample(n, replace = TRUE)),
+#'                 stringsAsFactors = TRUE)
 #' PlotGraph(x, y, ylab = "Random number", pch = 1,
 #'           seq.date.by = "days", scientific = TRUE)
 #'
@@ -120,7 +121,8 @@
 #'
 #' d <- data.frame(x = as.Date("2008-07-12") + 1:8 * 1000,
 #'                 y0 = c(NA, NA, 1, 3, 1, 4, 2, pi),
-#'                 y1 = c(1, 2, NA, NA, 4, 3, 2, pi))
+#'                 y1 = c(1, 2, NA, NA, 4, 3, 2, pi),
+#'                 stringsAsFactors = TRUE)
 #' PlotGraph(d, type = "i", ylim = c(0, 5), xpd = TRUE)
 #'
 
@@ -140,7 +142,7 @@ PlotGraph <- function(x, y, xlab, ylab, main=NULL, asp=NA, xlim=NULL, ylim=NULL,
   scipen <- getOption("scipen", default=0)
 
   if (inherits(x, c("data.frame", "matrix"))) {
-    if (inherits(x, "tbl_df")) x <- as.data.frame(x)
+    if (inherits(x, "tbl_df")) x <- as.data.frame(x, stringsAsFactors=TRUE)
     if (missing(y)) y <- x[, -1]
     x <- x[, 1]
   } else if (missing(y)) {
